Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH i-g-t] tests/xe_query: Also allow IP version less than 20 for BMG media
@ 2024-07-22 18:35 Matt Roper
  2024-07-22 18:53 ` Dixit, Ashutosh
                   ` (5 more replies)
  0 siblings, 6 replies; 8+ messages in thread
From: Matt Roper @ 2024-07-22 18:35 UTC (permalink / raw)
  To: igt-dev; +Cc: matthew.d.roper

Since BMG has a media version of 13.01, MTL/ARL are no longer the only
cases where we'll see IP versions lower than 20.  Add one more exception
to the final GT IP version sanity check.

Closes: https://gitlab.freedesktop.org/drm/xe/kernel/-/issues/2238
Signed-off-by: Matt Roper <matthew.d.roper@intel.com>
---
 tests/intel/xe_query.c | 13 +++++++++----
 1 file changed, 9 insertions(+), 4 deletions(-)

diff --git a/tests/intel/xe_query.c b/tests/intel/xe_query.c
index 84df24f49..c13613e0a 100644
--- a/tests/intel/xe_query.c
+++ b/tests/intel/xe_query.c
@@ -331,11 +331,16 @@ test_query_gt_list(int fd)
 				igt_assert_lte(1270, verx100);
 
 			/*
 			 * Aside from MTL/ARL, all version numbers should be
 			 * 20.00 or higher.
 			 */
-			if (!IS_METEORLAKE(dev_id))
-				igt_assert_lte(20, gt_list->gt_list[i].ip_ver_major);
+			if (IS_METEORLAKE(dev_id))
+				continue;
+			if (gt_list->gt_list[i].type == DRM_XE_QUERY_GT_TYPE_MEDIA &&
+			    IS_BATTLEMAGE(dev_id))
+				continue;
+
+			igt_assert_lte(20, gt_list->gt_list[i].ip_ver_major);
 		}
 	}
 }
@@ -331,11 +331,16 @@ test_query_gt_list(int fd)
 
 			/*
-			 * Aside from MTL/ARL, all version numbers should be
-			 * 20.00 or higher.
+			 * Aside from MTL/ARL and media on BMG, all version
+			 * numbers should be 20.00 or higher.
 			 */
-- 
2.45.2


^ permalink raw reply related	[flat|nested] 8+ messages in thread

end of thread, other threads:[~2024-07-23 10:50 UTC | newest]

Thread overview: 8+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-07-22 18:35 [PATCH i-g-t] tests/xe_query: Also allow IP version less than 20 for BMG media Matt Roper
2024-07-22 18:53 ` Dixit, Ashutosh
2024-07-22 19:15 ` ✓ CI.xeBAT: success for " Patchwork
2024-07-22 20:26   ` Matt Roper
2024-07-22 19:21 ` [PATCH i-g-t] " Gustavo Sousa
2024-07-22 19:25 ` ✓ Fi.CI.BAT: success for " Patchwork
2024-07-22 21:41 ` ✗ CI.xeFULL: failure " Patchwork
2024-07-23 10:50 ` ✗ Fi.CI.IGT: " Patchwork

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox